why use :code:`nbchkr`?
=======================

The design principles of :code:`nbchkr` are:

1. Lightweight with few dependencies;
2. Flat file outputs;
3. Customisable;
4. Well documented.

There are alternatives to :code:`nbchkr`, the most mature of which is
:code:`nbgrader` `<https://nbgrader.readthedocs.io>`_ which is a full course
management system. It includes the ability to send emails to students,
distribute assignments and feedback. It is a full featured class management
solution that I wholeheartedly recommend checking out in case it is the tool you
need.
